@@ -11,7 +11,7 @@ use List::MoreUtils qw(first_index);
 use Readonly;
 Readonly my $INDEX_NOT_FOUND => -1;
 
-use version 0.9917; our $VERSION = version->declare('v2.7.0');
+use version 0.9917; our $VERSION = version->declare('v2.7.1');
 
 
 sub new {
@@ -31,7 +31,11 @@ sub new {
         $self = WebService::Hexonet::Connector::ResponseTemplate->new( $self->{raw} );
     }
     $self = bless $self, $class;
-    $self->{command}     = $cmd;
+    $self->{command} = $cmd;
+    if ( defined $self->{command}->{PASSWORD} ) {
+        # make password no longer accessible
+        $self->{command}->{PASSWORD} = '***';
+    }
     $self->{columnkeys}  = [];
     $self->{columns}     = [];
     $self->{records}     = [];
